@@ -691,7 +691,8 @@ class DFSBase(object):
         if self.time_axis is TimeAxisType.CalendarNonEquidistant and self._currentTimeStep > 0 :
             ts = self.time_steps[TimeStep] - self.start_time
         else:
-            ts = self.time_step_size
+            ts = self.time_step_size * TimeStep
+
         if self.time_step_unit is TimeInterval.Second:
             time = ts.total_seconds()
         elif self.time_step_unit is TimeInterval.Minute:
@@ -699,9 +700,6 @@ class DFSBase(object):
         elif self.time_step_unit is TimeInterval.Hour:
             time = ts.total_seconds()/3600
         
-        time*=TimeStep
-
-      
       #Do we need to also add a new timestep
         if self.__end_of_file():
           if self._currentItem == self.number_of_items:
