@@ -234,7 +234,7 @@ class HydroTs(object):
 
     def durmedmin(self):
         val =medmin(self.time_series)
-        return Duration(self.time_series, val)
+        return self.Duration(self.time_series, val)
 
     def dur75(self):
         val =self.Q75()
@@ -253,8 +253,8 @@ class HydroTs(object):
         return self.duration( 7*val)
 
     def dur25(self):
-        val =Q25(self.time_series)
-        return Duration(self.time_series, val)
+        val = self.Q25(self.time_series)
+        return self.Duration(self.time_series, val)
 
     def pea1(self):
         val = self.Q50
@@ -270,7 +270,7 @@ class HydroTs(object):
         return np.mean([t for t in self.time_series if t>7*val])/val
 
     def pea25(self):
-        val =Q25(self.time_series)
+        val = self.Q25(self.time_series)
         return np.mean([t for t in self.time_series if t>val])/val
 
     def norises(self):
@@ -500,6 +500,11 @@ class GroundWaterBody(object):
         plt.show()
 
 
+
+def qh_function(H, A, H0, N):
+    return A *  max(0, H-H0)^N
+
+
 def read_sensorthings(url):
     """
     Reads a pandas time series from a VandWeb URL
@@ -519,7 +524,6 @@ def read_hydroinform_ts(sensorid, start=datetime(2020,1,1), end=datetime.now(),
     d=list(map(lambda s:pd.Timestamp(s['Time']), jdata))
     return pd.Series(l, d)
 
-
 def read_json_data(url):
     """
     Gets json data from a url
